#!/bin/bash
# This script together with 'anymeal.pro' allows the use of an image-database
# in qt-designer.
ln -s ../icons/hi32-action-checked.png checked.png
ln -s ../icons/hi32-action-connect.png connect.png
ln -s ../icons/hi32-action-contents.png contents.png
ln -s ../icons/hi32-action-dblogo.png dblogo.png
ln -s ../icons/hi32-action-delete.png delete.png
ln -s ../icons/hi32-action-deleteRecipe.png deleteRecipe.png
ln -s ../icons/hi32-action-editnew.png editnew.png
ln -s ../icons/hi32-action-exit.png exit.png
ln -s ../icons/hi32-action-exportDocbook.png exportDocbook.png
ln -s ../icons/hi32-action-exportFO.png exportFO.png
ln -s ../icons/hi32-action-exportHTML.png exportHTML.png
ln -s ../icons/hi32-action-exportMM.png exportMM.png
ln -s ../icons/hi32-action-export.png export.png
ln -s ../icons/hi32-action-exportRecipeML.png exportRecipeML.png
ln -s ../icons/hi32-action-help.png help.png
ln -s ../icons/hi32-action-importMM.png importMM.png
ln -s ../icons/hi32-action-import.png import.png
ln -s ../icons/hi32-action-search.png search.png
ln -s ../icons/hi32-action-toggle_log.png toggle_log.png
ln -s ../icons/hi32-action-unchecked.png unchecked.png
ln -s ../icons/hi32-action-uparrow.png uparrow.png
ln -s ../icons/hi32-action-downarrow.png downarrow.png
ln -s ../icons/hi32-app-anymeal.png anymeal.png
ln -s ../icons/hi32-action-importRecipeML.png importRecipeML.png

